@@ -7,7 +7,7 @@ RDF::Query::Parser::SPARQL11 - SPARQL 1.1 Parser.
 
 =head1 VERSION
 
-This document describes RDF::Query::Parser::SPARQL11 version 2.905_01.
+This document describes RDF::Query::Parser::SPARQL11 version 2.906_01.
 
 =head1 SYNOPSIS
 
@@ -47,7 +47,7 @@ use Scalar::Util qw(blessed looks_like_number reftype);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.905_01';
+	$VERSION	= '2.906_01';
 }
 
 ######################################################################
@@ -1050,6 +1050,9 @@ sub _DescribeQuery {
 	$self->__consume_ws_opt;
 	if ($self->_WhereClause_test) {
 		$self->_WhereClause;
+	} else {
+		my $pattern	= RDF::Query::Algebra::GroupGraphPattern->new();
+		$self->_add_patterns( $pattern );
 	}
 	
 	$self->__consume_ws_opt;
